This simulator is based on Ernest Koguc’s simulator (https://github.com/ernest-koguc/sf-simulator).
Minor changes have been done to bridge the gap of the original garbage
collected and object oriented design of the original into rust, but
otherwise, this is a direct port. As such, all credit for this
implementation, goes directly to him.
Apart from this, HafisCZ’s sf-tools (https://github.com/HafisCZ/sf-tools)
must also be credited. Sf-tools predates Ernest Koguc’s sim and was/is used
as a reference, both for results and code. The dungeon data used in the
simulations has also been imported and converted directly from that source
This is the numerical id of a player on a server. Note that in rare edge
cases this might be 0 (you are the first person to unlock the Dungeon. Who
do you fight?), but you can almost always expect this to be > 0
wherever found