pub struct IdleBuilding {
pub level: u32,
pub earning: BigInt,
pub cycle_start: Option<DateTime<Local>>,
pub cycle_end: Option<DateTime<Local>>,
pub golden: bool,
pub upgrade_cost: BigInt,
pub upgrade_cost_10x: BigInt,
pub upgrade_cost_25x: BigInt,
pub upgrade_cost_100x: BigInt,
}Expand description
A single building in the idle game
Fields
level: u32The current level of this building
earning: BigIntThe amount of money this earns on the next gather
cycle_start: Option<DateTime<Local>>The time at which this building started it’s production cycle. Note that this is likely to be in the past for quickly producing buildings
cycle_end: Option<DateTime<Local>>The time at which this building will finish it’s current production cycle. Note that this is likely to be in the past for quickly producing buildings
golden: boolHas the upgrade for this building been bought?
upgrade_cost: BigIntThe price to upgrade this building once
upgrade_cost_10x: BigIntThe price to upgrade this building 10x
upgrade_cost_25x: BigIntThe price to upgrade this building 25x
upgrade_cost_100x: BigIntThe price to upgrade this building 100x