ItemType

Enum ItemType 

pub enum ItemType {
Show 25 variants Hat, BreastPlate, Gloves, FootWear, Weapon { min_dmg: u32, max_dmg: u32, }, Amulet, Belt, Ring, Talisman, Shield { block_chance: u32, }, Shard { piece: u32, }, Potion(Potion), Scrapbook, DungeonKey { id: u32, shadow_key: bool, }, Gem(Gem), PetItem { typ: PetItem, }, QuickSandGlass, HeartOfDarkness, WheelOfFortune, Mannequin, Resource { amount: u32, typ: ResourceType, }, ToiletKey, Gral, EpicItemBag, Unknown(u8),
}
Identifies a specific item and contains all values related to the specific type. The only thing missing is armor, which can be found as a method on Item

Variants



Hat



BreastPlate



Gloves



FootWear



Weapon

Fields

min_dmg: u32
max_dmg: u32


Amulet



Belt



Ring



Talisman



Shield

Fields

block_chance: u32


Shard

Fields

piece: u32


Potion(Potion)



Scrapbook



DungeonKey

Fields

id: u32
shadow_key: bool


Gem(Gem)



PetItem

Fields



QuickSandGlass



HeartOfDarkness



WheelOfFortune



Mannequin



Resource

Fields

amount: u32


ToiletKey



Gral



EpicItemBag



Unknown(u8)

If there is a new item added to the game, this will be the placeholder to make sure you never think a place is empty somewhere, if it is not

Implementations

Source

impl ItemType

pub const fn is_weapon(self) -> bool

Checks if this item type is a weapon.

pub const fn is_shield(self) -> bool

Checks if this item type is a shield.

pub fn is_class_item(&self) -> bool

Checks if this type can only be worn by only a particular class

pub fn is_unique(&self) -> bool

Checks, if this item type is unique. Technically they are not always unique, as the scrapbook/keys can be sold, but it should be clear what this is

pub fn equipment_slot(&self) -> Option<EquipmentSlot>

The equipment slot, that this item type can be equipped to

pub fn is_enchantable(&self) -> bool

Checks, if this item type can be enchanted

pub fn raw_id(&self) -> u8

The id, that the server has associated with this item. I honestly forgot why I have this function public