Pets

Struct Pets 

pub struct Pets {
    pub total_collected: u16,
    pub rank: u32,
    pub honor: u32,
    pub max_pet_level: u16,
    pub opponent: PetOpponent,
    pub habitats: EnumMap<HabitatType, Habitat>,
    pub next_free_exploration: Option<DateTime<Local>>,
    pub atr_bonus: EnumMap<AttributeType, u32>,
}

Fields

total_collected: u16

The total amount of pets collected in all habitats

rank: u32

The rank this pet collection achieved in the hall of fame

honor: u32

The honor this pet collection has gained

max_pet_level: u16opponent: PetOpponent

Information about the pvp opponent you can attack with your pets

habitats: EnumMap<HabitatType, Habitat>

Information about all the different habitats

next_free_exploration: Option<DateTime<Local>>

The next time the exploration will be possible without spending a mushroom

atr_bonus: EnumMap<AttributeType, u32>

The bonus the player receives from pets

Implementations

Source

impl Pets

pub fn get_exploration_enemy(&self, habitat: HabitatType) -> Option<Monster>

Get the current monster we would be fighting, when

pub fn pet_to_fighter(&self, pet: &Pet, gladiator: u32) -> Fighter

Converts the given player pet into a fighter, usable in the simulation. The given pet does not need to have stats populated to work, since all stats will be dynamically calculated