Module session

Module session 

Re-exports

pub use crate::response::*;

Structs

ConnectionOptions
Options, that change the behavior of the communication with the server
PWHash
The password of a character, hashed in the way, that the server expects
ProxySettings
ServerConnection
Stores all information necessary to talk to the server. Notably, if you clone this, instead of creating this multiple times for characters on a server, this will use the same reqwest::Client, which can have slight benefits to performance
Session
The session, that manages the server communication for a character
SimpleSession